<p align="center">
  <a href="https://crates.io/crates/yaxp-common">
    <img alt="downloads" src="https://img.shields.io/crates/d/yaxp-common">
  </a>
</p>

# **<yaxp ⚡> Yet Another XSD Parser**

## Introduction
Using [roxmltree](https://github.com/RazrFalcon/roxmltree) to parse XML files. 

Converts xsd schema to:
- [x] json
- [x] arrow
- [ ] avro
- [ ] protobuf
- [x] jsonschema
- [x] json representation of spark schema
- [x] duckdb (read_csv columns/types)



## TODO

- [x] Add pyo3/maturin support (crate pyaxp)
- [ ] Add tests
